@@ -28,7 +28,7 @@ from linaro_image_tools.hwpack.packages import (
     FetchedPackage,
     get_packages_file,
     PackageMaker,
-    )
+)
 from linaro_image_tools.hwpack.hardwarepack_format import (
     HardwarePackFormatV1,
 )
@@ -43,6 +43,7 @@ from hwpack_fields import (
     BOOT_SCRIPT_FIELD,
     DTB_ADDR_FIELD,
     DTB_FILE_FIELD,
+    DTB_FILES_FIELD,
     EXTRA_SERIAL_OPTIONS_FIELD,
     FORMAT_FIELD,
     INITRD_ADDR_FIELD,
@@ -63,7 +64,9 @@ from hwpack_fields import (
     SAMSUNG_BL1_LEN_FIELD,
     SAMSUNG_BL1_START_FIELD,
     SAMSUNG_BL2_LEN_FIELD,
+    SAMSUNG_BL2_START_FIELD,
     SAMSUNG_ENV_LEN_FIELD,
+    SAMSUNG_ENV_START_FIELD,
     SERIAL_TTY_FIELD,
     SNOWBALL_STARTUP_FILES_CONFIG_FIELD,
     SUPPORT_FIELD,
@@ -125,10 +128,11 @@ class Metadata(object):
                       env_dd=None, boot_script=None,
                       bootloader_file_in_boot_part=None,
                       uboot_dd=None, spl_in_boot_part=None, spl_dd=None,
-                      extra_serial_opts=None, loader_start=None,
+                      extra_serial_options=None, loader_start=None,
                       snowball_startup_files_config=None,
                       samsung_bl1_start=None, samsung_bl1_len=None,
-                      samsung_env_len=None, samsung_bl2_len=None):
+                      samsung_env_start=None, samsung_env_len=None,
+                      samsung_bl2_start=None, samsung_bl2_len=None):
         """Add fields that are specific to the new format.
 
         These fields are not present in earlier config files.
@@ -158,22 +162,26 @@ class Metadata(object):
         self.spl_in_boot_part = spl_in_boot_part
         self.spl_dd = spl_dd
         self.env_dd = env_dd
-        self.extra_serial_opts = extra_serial_opts
+        self.extra_serial_options = extra_serial_options
         self.snowball_startup_files_config = snowball_startup_files_config
         self.samsung_bl1_start = samsung_bl1_start
         self.samsung_bl1_len = samsung_bl1_len
+        self.samsung_env_start = samsung_env_start
         self.samsung_env_len = samsung_env_len
+        self.samsung_bl2_start = samsung_bl2_start
         self.samsung_bl2_len = samsung_bl2_len
 
     @classmethod
-    def add_v3_config(self, boards=None, bootloaders=None):
+    def add_v3_config(self, boards=None, bootloaders=None, dtb_files=None):
         """Add fields that are specific to the v3 config format.
         These fields are not present in the earlier config files.
 
         :param boards: The boards section of the hwpack.
-        :param bootloaders: The bootloaders section of the hwpack."""
+        :param bootloaders: The bootloaders section of the hwpack.
+        :param dtb_files: The dtb_files section of the hwpack."""
         self.boards = boards
         self.bootloaders = bootloaders
+        self.dtb_files = dtb_files
 
     @classmethod
     def from_config(cls, config, version, architecture):
@@ -208,7 +216,7 @@ class Metadata(object):
                 dtb_file=config.dtb_file,
                 env_dd=config.env_dd,
                 extra_boot_options=config.extra_boot_options,
-                extra_serial_opts=config.extra_serial_opts,
+                extra_serial_options=config.extra_serial_options,
                 initrd_addr=config.initrd_addr,
                 initrd=config.initrd,
                 kernel_addr=config.kernel_addr,
@@ -221,21 +229,24 @@ class Metadata(object):
                 samsung_bl1_len=config.samsung_bl1_len,
                 samsung_bl1_start=config.samsung_bl1_start,
                 samsung_bl2_len=config.samsung_bl2_len,
+                samsung_bl2_start=config.samsung_bl2_start,
                 samsung_env_len=config.samsung_env_len,
+                samsung_env_start=config.samsung_env_start,
                 serial_tty=config.serial_tty,
                 snowball_startup_files_config=snowball_startup_config,
                 spl_dd=config.spl_dd,
                 spl_in_boot_part=config.spl_in_boot_part,
                 uboot_dd=config.bootloader_dd,
                 bootloader_file_in_boot_part=config.
-                    bootloader_file_in_boot_part,
+                bootloader_file_in_boot_part,
                 vmlinuz=config.vmlinuz,
                 wired_interfaces=config.wired_interfaces,
                 wireless_interfaces=config.wireless_interfaces,
-                )
+            )
         if config.format.format_as_string == '3.0':
             metadata.add_v3_config(boards=config.boards,
-                                    bootloaders=config.bootloaders)
+                                   bootloaders=config.bootloaders,
+                                   dtb_files=config.dtb_files)
         return metadata
 
     def __str__(self):
@@ -305,26 +316,32 @@ class Metadata(object):
         if self.dtb_file is not None:
             # XXX In V3 this one should be a list, called dtb_files.
             metadata += dump({DTB_FILE_FIELD: self.dtb_file})
+        if self.dtb_files is not None:
+            metadata += dump({DTB_FILES_FIELD: self.dtb_files})
         if self.boot_script is not None:
             metadata += dump({BOOT_SCRIPT_FIELD: self.boot_script})
-        if self.extra_serial_opts is not None:
+        if self.extra_serial_options is not None:
             # XXX Check why and where once we get a list once a string.
-            if isinstance(self.extra_serial_opts, list):
-                extra_serial_options = " ".join(self.extra_serial_opts)
+            if isinstance(self.extra_serial_options, list):
+                extra_serial_options = " ".join(self.extra_serial_options)
             else:
-                extra_serial_options = self.extra_serial_opts
+                extra_serial_options = self.extra_serial_options
             metadata += dump({
-                            EXTRA_SERIAL_OPTIONS_FIELD:
-                            extra_serial_options})
+                EXTRA_SERIAL_OPTIONS_FIELD:
+                extra_serial_options})
         if self.snowball_startup_files_config is not None:
             metadata += dump({SNOWBALL_STARTUP_FILES_CONFIG_FIELD:
-                                self.snowball_startup_files_config})
+                              self.snowball_startup_files_config})
         if self.samsung_bl1_start is not None:
             metadata += dump({SAMSUNG_BL1_START_FIELD: self.samsung_bl1_start})
         if self.samsung_bl1_len is not None:
             metadata += dump({SAMSUNG_BL1_LEN_FIELD: self.samsung_bl1_len})
+        if self.samsung_env_start is not None:
+            metadata += dump({SAMSUNG_ENV_START_FIELD: self.samsung_env_start})
         if self.samsung_env_len is not None:
             metadata += dump({SAMSUNG_ENV_LEN_FIELD: self.samsung_env_len})
+        if self.samsung_bl2_start is not None:
+            metadata += dump({SAMSUNG_BL2_START_FIELD: self.samsung_bl2_start})
         if self.samsung_bl2_len is not None:
             metadata += dump({SAMSUNG_BL2_LEN_FIELD: self.samsung_bl2_len})
         return metadata
@@ -400,8 +417,8 @@ class Metadata(object):
             metadata += "SPL_DD=%s\n" % self.spl_dd
         if self.env_dd is not None:
             metadata += "ENV_DD=%s\n" % self.env_dd
-        if self.extra_serial_opts is not None:
-            metadata += "EXTRA_SERIAL_OPTIONS=%s\n" % self.extra_serial_opts
+        if self.extra_serial_options is not None:
+            metadata += "EXTRA_SERIAL_OPTIONS=%s\n" % self.extra_serial_options
         if self.snowball_startup_files_config is not None:
             metadata += "SNOWBALL_STARTUP_FILES_CONFIG=%s\n" % (
                 self.snowball_startup_files_config)
@@ -409,8 +426,12 @@ class Metadata(object):
             metadata += "SAMSUNG_BL1_START=%s\n" % self.samsung_bl1_start
         if self.samsung_bl1_len is not None:
             metadata += "SAMSUNG_BL1_LEN=%s\n" % self.samsung_bl1_len
+        if self.samsung_env_start is not None:
+            metadata += "SAMSUNG_ENV_START=%s\n" % self.samsung_env_start
         if self.samsung_env_len is not None:
             metadata += "SAMSUNG_ENV_LEN=%s\n" % self.samsung_env_len
+        if self.samsung_bl2_start is not None:
+            metadata += "SAMSUNG_BL2_START=%s\n" % self.samsung_bl2_start
         if self.samsung_bl2_len is not None:
             metadata += "SAMSUNG_BL2_LEN=%s\n" % self.samsung_bl2_len
         return metadata
