@@ -32,10 +32,12 @@ from parted import (
     Disk,
     PARTITION_NORMAL,
     PARTITION_EXTENDED,
-    )
+)
 
 from linaro_image_tools import cmd_runner
 
+logger = logging.getLogger(__name__)
+
 HEADS = 128
 SECTORS = 32
 SECTOR_SIZE = 512  # bytes
@@ -52,7 +54,8 @@ MIN_IMAGE_SIZE = ROUND_IMAGE_TO
 
 
 def setup_android_partitions(board_config, media, image_size, bootfs_label,
-                     should_create_partitions, should_align_boot_part=False):
+                             should_create_partitions,
+                             should_align_boot_part=False):
     cylinders = None
     if not media.is_block_device:
         image_size_in_bytes = get_partition_size_in_bytes(image_size)
@@ -161,10 +164,15 @@ def setup_partitions(board_config, media, image_size, bootfs_label,
 
     if should_format_bootfs:
         print "\nFormating boot partition\n"
-        proc = cmd_runner.run(
-            ['mkfs.vfat', '-F', str(board_config.fat_size), bootfs, '-n',
-             bootfs_label],
-            as_root=True)
+        mkfs = 'mkfs.%s' % board_config.bootfs_type
+        if board_config.bootfs_type == 'vfat':
+            proc = cmd_runner.run(
+                [mkfs, '-F', str(board_config.fat_size), bootfs, '-n',
+                 bootfs_label],
+                as_root=True)
+        else:
+            proc = cmd_runner.run(
+                [mkfs, bootfs, '-L', bootfs_label], as_root=True)
         proc.wait()
 
     if should_format_rootfs:
@@ -205,7 +213,6 @@ def partition_mounted(device, path, *args):
         try:
             umount(path)
         except cmd_runner.SubcommandNonZeroReturnValue, e:
-            logger = logging.getLogger("linaro_image_tools")
             logger.warn("Failed to umount %s, but ignoring it because of a "
                         "previous error" % path)
             logger.warn(e)
@@ -303,7 +310,7 @@ def calculate_partition_size_and_offset(image_file):
     for partition in disk.partitions:
         assert partition.type == PARTITION_NORMAL, (
             "Parted should only return normal partitions but got type %i" %
-                partition.type)
+            partition.type)
         if 'boot' in partition.getFlagsAsString():
             geometry = partition.geometry
             vfat_offset = geometry.start * SECTOR_SIZE
@@ -586,7 +593,6 @@ def wait_partition_to_settle(media):
 
     :param media: A setup_partitions.Media object to partition.
     """
-    logger = logging.getLogger("linaro_image_tools")
     tts = 1
     while (tts > 0) and (tts <= MAX_TTS):
         try:
