@@ -28,6 +28,17 @@ import sys
 
 from linaro_image_tools import cmd_runner
 
+DEFAULT_LOGGER_NAME = 'linaro_image_tools'
+
+# The boot path in the boot tarball.
+BOOT_DIR_IN_TARBALL = "boot"
+# The name of the hwpack file found in the boot tarball.
+HWPACK_NAME = "config"
+
+# dconf keys to disable automount options.
+AUTOMOUNT_DCONF_KEY = '/org/gnome/desktop/media-handling/automount'
+AUTOMOUNT_OPEN_DCONF_KEYU = '/org/gnome/desktop/media-handling/automount-open'
+
 
 # try_import was copied from python-testtools 0.9.12 and was originally
 # licensed under a MIT-style license but relicensed under the GPL in Linaro
@@ -76,13 +87,15 @@ CommandNotFound = try_import('CommandNotFound.CommandNotFound')
 
 
 def path_in_tarfile_exists(path, tar_file):
-    tarinfo = tarfile.open(tar_file, 'r:gz')
+    exists = True
     try:
+        tarinfo = tarfile.open(tar_file, 'r:gz')
         tarinfo.getmember(path)
-        return True
+        tarinfo.close()
     except KeyError:
-        return False
-    tarinfo.close()
+        exists = False
+    finally:
+        return exists
 
 
 def verify_file_integrity(sig_file_list):
@@ -120,11 +133,11 @@ def verify_file_integrity(sig_file_list):
 
         try:
             sha1sums_out, _ = cmd_runner.Popen(
-                                            ['sha1sum', '-c', hash_file],
-                                            stdout=subprocess.PIPE,
-                                            stderr=subprocess.STDOUT,
-                                            cwd=sha_cwd
-                                            ).communicate()
+                ['sha1sum', '-c', hash_file],
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+                cwd=sha_cwd
+            ).communicate()
         except cmd_runner.SubcommandNonZeroReturnValue as inst:
             sha1sums_out = inst.stdout
 
@@ -145,24 +158,24 @@ def check_file_integrity_and_log_errors(sig_file_list, binary, hwpacks):
 
     # Check the outputs from verify_file_integrity
     # Abort if anything fails.
+    logger = logging.getLogger(__name__)
     if len(sig_file_list):
         if not gpg_sig_pass:
-            logging.error("GPG signature verification failed.")
+            logger.error("GPG signature verification failed.")
             return False, []
 
         if not os.path.basename(binary) in verified_files:
-            logging.error("OS Binary verification failed")
+            logger.error("OS Binary verification failed")
             return False, []
 
         for hwpack in hwpacks:
             if not os.path.basename(hwpack) in verified_files:
-                logging.error("Hwpack {0} verification failed".format(hwpack))
+                logger.error("Hwpack {0} verification failed".format(hwpack))
                 return False, []
 
         for verified_file in verified_files:
-            logging.info('Hash verification of file {0} OK.'.format(
-                                                                verified_file))
-
+            logger.info('Hash verification of file {0} OK.'.format(
+                verified_file))
     return True, verified_files
 
 
@@ -177,7 +190,7 @@ def install_package_providing(command):
 
     if CommandNotFound is None:
         raise UnableToFindPackageProvidingCommand(
-            "Cannot lookup a package which provides %s" % command)
+            "CommandNotFound python module does not exist.")
 
     packages = CommandNotFound().getPackages(command)
     if len(packages) == 0:
@@ -205,15 +218,15 @@ def install_package_providing(command):
             print "Package installation is necessary to continue. Exiting."
             sys.exit(1)
         print ("Installing required command '%s' from package '%s'..."
-                % (command, package))
+               % (command, package))
         cmd_runner.run(['apt-get', '--yes', 'install', package],
-                        as_root=True).wait()
+                       as_root=True).wait()
     except EOFError:
         raise PackageInstallationRefused(
-                            "Package installation interrupted: input error.")
+            "Package installation interrupted: input error.")
     except KeyboardInterrupt:
         raise PackageInstallationRefused(
-                            "Package installation interrupted by the user.")
+            "Package installation interrupted by the user.")
 
 
 def has_command(command):
@@ -342,9 +355,97 @@ def additional_option_checks(args):
                 "--hwpack argument (%s) is not a regular file" % hwpack)
 
 
+def additional_android_option_checks(args):
+    """Checks that some of the args passed to l-a-m-c are valid."""
+    if args.hwpack:
+        if not os.path.isfile(args.hwpack):
+            raise InvalidHwpackFile(
+                "--hwpack argument (%s) is not a regular file" % args.hwpack)
+
+
+def android_hwpack_in_boot_tarball(boot_dir):
+    """Simple check for existence of a path.
+
+    Needed to make cli command testable in some way.
+    :param boot_dir: The path where the boot tarball has been extracted.
+    :type str
+    :return A tuple with a bool if the path exists, and the path to the config
+            file.
+    """
+    conf_file = os.path.join(boot_dir, BOOT_DIR_IN_TARBALL, HWPACK_NAME)
+    return os.path.exists(conf_file), conf_file
+
+
 def check_required_args(args):
     """Check that the required args are passed."""
     if args.dev is None:
         raise MissingRequiredOption("--dev option is required")
     if args.binary is None:
         raise MissingRequiredOption("--binary option is required")
+
+
+def get_logger(name=DEFAULT_LOGGER_NAME, debug=False):
+    """
+    Retrieves a named logger. Default name is set in the variable
+    DEFAULT_LOG_NAME. Debug is set to False by default.
+
+    :param name: The name of the logger.
+    :param debug: If debug level should be turned on
+    :return: A logger instance.
+    """
+    logger = logging.getLogger(name)
+    ch = logging.StreamHandler()
+
+    if debug:
+        ch.setLevel(logging.DEBUG)
+        formatter = logging.Formatter(
+            "%(asctime)s - %(name)s - %(levelname)s - %(message)s")
+        ch.setFormatter(formatter)
+        logger.setLevel(logging.DEBUG)
+    else:
+        ch.setLevel(logging.INFO)
+        formatter = logging.Formatter("%(message)s")
+        ch.setFormatter(formatter)
+        logger.setLevel(logging.INFO)
+
+    logger.addHandler(ch)
+    return logger
+
+
+def disable_automount():
+    """Disables the desktop environment automount option.
+
+    This will work only under GNOME with dconf installed.
+    """
+    logger = logging.getLogger(DEFAULT_LOGGER_NAME)
+
+    if has_command('dconf'):
+        logger.info("Disabling desktop environment automount option.")
+        try:
+            cmd_runner.run(
+                ['dconf', 'write', AUTOMOUNT_DCONF_KEY, 'false'],
+                stdout=open('/dev/null', 'w')).wait()
+            cmd_runner.run(
+                ['dconf', 'write', AUTOMOUNT_OPEN_DCONF_KEYU, 'false'],
+                stdout=open('/dev/null', 'w')).wait()
+        except cmd_runner.SubcommandNonZeroReturnValue:
+            logger.error("Error disabling desktop environemnt automount.")
+
+
+def enable_automount():
+    """Re-enables back the desktop environment automount option.
+
+    This will work only under GNOME with dconf installed. It should be run
+    as an atexit function.
+    """
+    logger = logging.getLogger(DEFAULT_LOGGER_NAME)
+    if has_command('dconf'):
+        try:
+            cmd_runner.run(
+                ['dconf', 'write', AUTOMOUNT_DCONF_KEY, 'true'],
+                stdout=open('/dev/null', 'w')).wait()
+            cmd_runner.run(
+                ['dconf', 'write', AUTOMOUNT_OPEN_DCONF_KEYU, 'true'],
+                stdout=open('/dev/null', 'w')).wait()
+        except cmd_runner.SubcommandNonZeroReturnValue:
+            logger.error("Error enabling back desktop environemnt automount.")
